@@ -68,7 +68,7 @@ Domain::Artifact::Ptr ContextPageModel::addItem(const QString &title, const QMod
 
     const auto job = parentTask ? m_taskRepository->createChild(task, parentTask)
                    : m_taskRepository->createInContext(task, m_context);
-    installHandler(job, tr("Cannot add task %1 in context %2").arg(title).arg(m_context->name()));
+    installHandler(job, tr("Cannot add task %1 in context %2").arg(title, m_context->name()));
 
     return task;
 }
@@ -80,7 +80,7 @@ void ContextPageModel::removeItem(const QModelIndex &index)
     auto task = artifact.objectCast<Domain::Task>();
     const auto job = index.parent().isValid() ? m_taskRepository->dissociate(task)
                    : m_contextRepository->dissociate(m_context, task);
-    installHandler(job, tr("Cannot remove task %1 from context %2").arg(task->title()).arg(m_context->name()));
+    installHandler(job, tr("Cannot remove task %1 from context %2").arg(task->title(), m_context->name()));
 }
 
 void ContextPageModel::promoteItem(const QModelIndex &index)
@@ -139,12 +139,12 @@ QAbstractItemModel *ContextPageModel::createCentralListModel()
             task->setDone(value.toInt() == Qt::Checked);
 
         const auto job = m_taskRepository->update(task);
-        installHandler(job, tr("Cannot modify task %1 in context %2").arg(currentTitle).arg(m_context->name()));
+        installHandler(job, tr("Cannot modify task %1 in context %2").arg(currentTitle, m_context->name()));
         return true;
     };
 
     auto drop = [this] (const QMimeData *mimeData, Qt::DropAction, const Domain::Task::Ptr &parentTask) {
-        if (!mimeData->hasFormat("application/x-zanshin-object"))
+        if (!mimeData->hasFormat(QStringLiteral("application/x-zanshin-object")))
             return false;
 
         auto droppedArtifacts = mimeData->property("objects").value<Domain::Artifact::List>();
@@ -190,12 +190,13 @@ QAbstractItemModel *ContextPageModel::createCentralListModel()
             return Q_NULLPTR;
 
         auto draggedArtifacts = Domain::Artifact::List();
+        draggedArtifacts.reserve(tasks.size());
         foreach (const Domain::Task::Ptr &task, tasks) {
             draggedArtifacts.append(task.objectCast<Domain::Artifact>());
         }
 
         auto data = new QMimeData();
-        data->setData("application/x-zanshin-object", "object");
+        data->setData(QStringLiteral("application/x-zanshin-object"), "object");
         data->setProperty("objects", QVariant::fromValue(draggedArtifacts));
         return data;
     };
