@@ -89,6 +89,7 @@ AvailablePagesView::AvailablePagesView(QWidget *parent)
     actionBar->addAction(m_removeAction);
 
     auto actionBarLayout = new QHBoxLayout;
+    actionBarLayout->setContentsMargins(0, 0, 0, 0);
     actionBarLayout->setAlignment(Qt::AlignRight);
     actionBarLayout->addWidget(actionBar);
 
@@ -97,6 +98,10 @@ AvailablePagesView::AvailablePagesView(QWidget *parent)
     layout->addLayout(actionBarLayout);
     setLayout(layout);
 
+    auto margins = layout->contentsMargins();
+    margins.setBottom(0);
+    layout->setContentsMargins(margins);
+
     m_projectDialogFactory = [] (QWidget *parent) {
         return NewProjectDialogPtr(new NewProjectDialog(parent));
     };
